import request from '@/utils/request'

// 获取表单的查询字段、按钮、表头信息
export function getTableQuery(data) {
  return request({
    url: '/boman-web-core/p/cs/getTableQuery',
    method: 'POST',
    data
  })
}
// 获取单表单数据
export function getObject(data) {
  return request({
    url: '/boman-web-core/p/cs/getObject',
    method: 'POST',
    data
  })
}
// 获取表单tab数据
 export function geteditindeTab(data) {
   return request({
     url: '/boman-web-core/p/cs/objectTab',
     method: 'POST',
     data
   })
 }

 export function listIndex(data) {
   return request({
     url: '/boman-web-core/p/cs/queryList',
     method: 'post',
     data: data
   })
 }

 // 删除菜单
 export function delMenutabform(data) {
   return request({
     url: 'boman-web-core/p/cs/objectDelete',
     method: 'POST',
     data
   })
 }

 // 提交
 export function tableSubimt(data) {
   return request({
     url: '/boman-web-core/p/cs/objectSubmit',
     method: 'POST',
     data
   })
 }
  // 反提交
  export function tableSubimtanit(data) {
    return request({
      url: '/boman-web-core/p/cs/objectUnSubmit',
      method: 'POST',
      data
    })
  }
  // 保存
  export function addbjectSave(data) {
    return request({
      url: '/boman-web-core/p/cs/objectSave',
      method: 'POST',
      data
    })
  }
